==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ShapeFilterRecordEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapefileRecordDescriptionMetadata } from "./ShapefileRecordDescriptionMetadata";
import { ShapeFilterRecordEventArgsDescription } from "./ShapeFilterRecordEventArgsDescription";
/**
 * @hidden
 */
var ShapeFilterRecordEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ShapeFilterRecordEventArgsDescriptionMetadata, _super);
    function ShapeFilterRecordEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ShapeFilterRecordEventArgsDescriptionMetadata.b = function (a) {
        if (ShapeFilterRecordEventArgsDescriptionMetadata.a == null) {
            ShapeFilterRecordEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ShapeFilterRecordEventArgsDescriptionMetadata.c(ShapeFilterRecordEventArgsDescriptionMetadata.a);
        }
        if (a.g(ShapeFilterRecordEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ShapeFilterRecordEventArgsDescriptionMetadata.a);
        ShapefileRecordDescriptionMetadata.d(a);
    };
    ShapeFilterRecordEventArgsDescriptionMetadata.c = function (a) {
        a.item("Record", "ExportedType:ShapefileRecord");
        a.item("ShouldInclude", "Boolean");
    };
    ShapeFilterRecordEventArgsDescriptionMetadata.d = function (a) {
        ShapeFilterRecordEventArgsDescriptionMetadata.b(a);
        a.u("ShapeFilterRecordEventArgs", function () { return new ShapeFilterRecordEventArgsDescription(); });
        a.t("ShapeFilterRecordEventArgs", ShapeFilterRecordEventArgsDescriptionMetadata.a);
    };
    ShapeFilterRecordEventArgsDescriptionMetadata.$t = markType(ShapeFilterRecordEventArgsDescriptionMetadata, 'ShapeFilterRecordEventArgsDescriptionMetadata');
    ShapeFilterRecordEventArgsDescriptionMetadata.a = null;
    return ShapeFilterRecordEventArgsDescriptionMetadata;
}(Base));
export { ShapeFilterRecordEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ShapeFilterRecordEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapefileRecordDescriptionMetadata } from "./ShapefileRecordDescriptionMetadata";
import { ShapeFilterRecordEventArgsDescription } from "./ShapeFilterRecordEventArgsDescription";
/**
 * @hidden
 */
var ShapeFilterRecordEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ShapeFilterRecordEventArgsDescriptionMetadata, _super);
    function ShapeFilterRecordEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ShapeFilterRecordEventArgsDescriptionMetadata.b = function (a) {
        if (ShapeFilterRecordEventArgsDescriptionMetadata.a == null) {
            ShapeFilterRecordEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ShapeFilterRecordEventArgsDescriptionMetadata.c(ShapeFilterRecordEventArgsDescriptionMetadata.a);
        }
        if (a.j(ShapeFilterRecordEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ShapeFilterRecordEventArgsDescriptionMetadata.a);
        ShapefileRecordDescriptionMetadata.d(a);
    };
    ShapeFilterRecordEventArgsDescriptionMetadata.c = function (a) {
        a.item("Record", "ExportedType:ShapefileRecord");
        a.item("ShouldInclude", "Boolean");
    };
    ShapeFilterRecordEventArgsDescriptionMetadata.d = function (a) {
        ShapeFilterRecordEventArgsDescriptionMetadata.b(a);
        a.aa("ShapeFilterRecordEventArgs", function () { return new ShapeFilterRecordEventArgsDescription(); });
        a.z("ShapeFilterRecordEventArgs", ShapeFilterRecordEventArgsDescriptionMetadata.a);
    };
    ShapeFilterRecordEventArgsDescriptionMetadata.$t = markType(ShapeFilterRecordEventArgsDescriptionMetadata, 'ShapeFilterRecordEventArgsDescriptionMetadata');
    ShapeFilterRecordEventArgsDescriptionMetadata.a = null;
    return ShapeFilterRecordEventArgsDescriptionMetadata;
}(Base));
export { ShapeFilterRecordEventArgsDescriptionMetadata };
